@@ -2,16 +2,16 @@
 
 % Copyright Notice
 %
-%    Copyright (C) 2013 SUPELEC
+%    Copyright (C) 2017 CentraleSupelec
 %
-%    Author: Julien Bect  <julien.bect@centralesupelec.fr>
+%    Author:  Julien Bect  <julien.bect@centralesupelec.fr>
 
 % Copying Permission Statement
 %
 %    This file is part of
 %
 %            STK: a Small (Matlab/Octave) Toolbox for Kriging
-%               (http://sourceforge.net/projects/kriging)
+%               (https://github.com/stk-kriging/stk/)
 %
 %    STK is free software: you can redistribute it and/or modify it under
 %    the terms of the GNU General Public License as published by the Free
@@ -26,13 +26,8 @@
 %    You should  have received a copy  of the GNU  General Public License
 %    along with STK.  If not, see <http://www.gnu.org/licenses/>.
 
-function y = and(x1, x2)
+function y = and (x1, x2)
 
-y = bsxfun(@and, x1, x2);
+y = (logical (x1) & logical (x2));
 
 end % function
-
-%!test  stk_test_dfbinaryop(@and, floor(3*rand(7, 2)), floor(3*rand(7, 2)));
-%!test  stk_test_dfbinaryop(@and, floor(3*rand(7, 2)), 1.0);
-%!error stk_test_dfbinaryop(@and, floor(3*rand(7, 2)), floor(3*rand(7, 3)));
-
