@@ -4,14 +4,14 @@
 %
 %    Copyright (C) 2013 SUPELEC
 %
-%    Author: Julien Bect  <julien.bect@supelec.fr>
+%    Author: Julien Bect  <julien.bect@centralesupelec.fr>
 
 % Copying Permission Statement
 %
 %    This file is part of
 %
 %            STK: a Small (Matlab/Octave) Toolbox for Kriging
-%               (http://sourceforge.net/projects/kriging)
+%               (https://github.com/stk-kriging/stk/)
 %
 %    STK is free software: you can redistribute it and/or modify it under
 %    the terms of the GNU General Public License as published by the Free
@@ -30,7 +30,7 @@ function y = rdivide(x1, x2)
 
 y = bsxfun(@rdivide, x1, x2);
 
-end % function rdivide
+end % function
 
 %!test  stk_test_dfbinaryop(@rdivide, rand(7, 2), 1 + rand(7, 2));
 %!test  stk_test_dfbinaryop(@rdivide, rand(7, 2), pi);
