@@ -1,17 +1,17 @@
-% DISP [overloaded base function]
+% DISP [overload base function]
 
 % Copyright Notice
 %
 %    Copyright (C) 2014 SUPELEC
 %
-%    Author:  Julien Bect  <julien.bect@supelec.fr>
+%    Author:  Julien Bect  <julien.bect@centralesupelec.fr>
 
 % Copying Permission Statement
 %
 %    This file is part of
 %
 %            STK: a Small (Matlab/Octave) Toolbox for Kriging
-%               (http://sourceforge.net/projects/kriging)
+%               (https://github.com/stk-kriging/stk/)
 %
 %    STK is free software: you can redistribute it and/or modify it under
 %    the terms of the GNU General Public License as published by the Free
@@ -30,4 +30,4 @@ function disp (hr)
 
 disp (hr.stk_dataframe);
 
-end % function disp
+end % function
