@@ -2,7 +2,7 @@
 
 % Copyright Notice
 %
-%    Copyright (C) 2015 CentraleSupelec
+%    Copyright (C) 2015, 2018 CentraleSupelec
 %
 %    Author:  Julien Bect  <julien.bect@centralesupelec.fr>
 
@@ -11,7 +11,7 @@
 %    This file is part of
 %
 %            STK: a Small (Matlab/Octave) Toolbox for Kriging
-%               (http://sourceforge.net/projects/kriging)
+%               (https://github.com/stk-kriging/stk/)
 %
 %    STK is free software: you can redistribute it and/or modify it under
 %    the terms of the GNU General Public License as published by the Free
@@ -28,10 +28,6 @@
 
 function box = stk_boundingbox (x)
 
-if nargin > 1,
-    stk_error ('Too many input arguments.', 'TooManyInputArgs');
-end
-
 % An stk_hrect object is its own bounding box
 box = x;
 
@@ -46,6 +42,5 @@ end % function
 
 %!error  y = stk_boundingbox ();
 %!test   y = stk_boundingbox (x);
-%!error  y = stk_boundingbox (x, 1);
 
 %!assert (isequal (y, x));
