@@ -23,7 +23,7 @@
 
 % Copyright Notice
 %
-%    Copyright (C) 2015, 2017 CentraleSupelec
+%    Copyright (C) 2015, 2017, 2018 CentraleSupelec
 %    Copyright (C) 2014 SUPELEC
 %
 %    Author:  Julien Bect  <julien.bect@centralesupelec.fr>
@@ -33,7 +33,7 @@
 %    This file is part of
 %
 %            STK: a Small (Matlab/Octave) Toolbox for Kriging
-%               (http://sourceforge.net/projects/kriging)
+%               (https://github.com/stk-kriging/stk/)
 %
 %    STK is free software: you can redistribute it and/or modify it under
 %    the terms of the GNU General Public License as published by the Free
@@ -50,11 +50,7 @@
 
 function s = stk_hrect (arg1, colnames)
 
-if nargin > 2,
-    
-    stk_error ('Too many input arguments.', 'TooManyInputArgs');
-    
-elseif nargin == 0  % Default constructor
+if nargin == 0  % Default constructor
     
     df = stk_dataframe ();
     s = class (struct (), 'stk_hrect', df);
@@ -66,17 +62,25 @@ elseif isa (arg1, 'stk_hrect')  % arg1 is already an stk_hrect object: copy
     
 else  % create a new stk_hrect object
     
-    % NOTE: the following test uses (prod (size (arg1)) == 1) instead of
-    % isscalar because isscalar (x) means (numel (x) == 1) in Octave 3.8.2
-    % and therefore always returns true for stk_dataframe objects.
-    
-    if (prod (size (arg1)) == 1)  % arg1 is the dimension of the input space
+    if (prod (size (arg1)) == 1)  % isscalar CG#08
+        % arg1 is the dimension of the input space
         % => create a default hyper-rectangle [0; 1]^d, with d = arg1
+        
         d = arg1;
         box_data = repmat ([0; 1], 1, d);
+        box_colnames = {};
+        
     else
+        
+        if isa (arg1, 'stk_dataframe')
+            box_colnames = get (arg1, 'colnames');
+        else
+            box_colnames = {};
+        end
+        
         box_data = double (arg1);
         d = size (box_data, 2);
+        
         if (~ isequal (size (box_data), [2 d]))
             stk_error ('Invalid size: should be 2 x dim.', 'IncorrectSize');
         end
@@ -86,7 +90,8 @@ else  % create a new stk_hrect object
         stk_error ('Invalid bounds', 'InvalidBounds');
     end
     
-    df = stk_dataframe (box_data, {}, {'lower_bounds', 'upper_bounds'});
+    df = stk_dataframe (box_data, ...
+        box_colnames, {'lower_bounds', 'upper_bounds'});
     s = class (struct (), 'stk_hrect', df);
     
 end
@@ -98,5 +103,13 @@ end
 
 end % function
 
+%#ok<*PSIZE>
+
 
 %!test stk_test_class ('stk_hrect')
+
+%!shared dom
+%!test dom = stk_hrect ([-1; 1], {'x'});
+%!assert (isequal (dom.colnames, {'x'}))
+%!assert (isequal (dom.rownames, {'lower_bounds'; 'upper_bounds'}))
+%!assert (isequal (dom.data, [-1; 1]))
