@@ -1,4 +1,4 @@
-% LINSOLVE  [STK internal]
+% LINSOLVE [STK internal]
 %
 % CALL: w = linsolve (kreq, rs)
 %
@@ -16,7 +16,7 @@
 %    This file is part of
 %
 %            STK: a Small (Matlab/Octave) Toolbox for Kriging
-%               (http://sourceforge.net/projects/kriging)
+%               (https://github.com/stk-kriging/stk/)
 %
 %    STK is free software: you can redistribute it and/or modify it under
 %    the terms of the GNU General Public License as published by the Free
@@ -33,7 +33,7 @@
 
 function w = linsolve (kreq, rs)
 
-if nargin < 2,
+if nargin < 2
     rs = kreq.RS;
 end
 
