@@ -4,14 +4,14 @@
 %
 %    Copyright (C) 2014 SUPELEC
 %
-%    Authors:  Julien Bect  <julien.bect@supelec.fr>
+%    Authors:  Julien Bect  <julien.bect@centralesupelec.fr>
 
 % Copying Permission Statement
 %
 %    This file is part of
 %
 %            STK: a Small (Matlab/Octave) Toolbox for Kriging
-%               (http://sourceforge.net/projects/kriging)
+%               (https://github.com/stk-kriging/stk/)
 %
 %    STK is free software: you can redistribute it and/or modify it under
 %    the terms of the GNU General Public License as published by the Free
@@ -33,4 +33,4 @@ t = sum (Pi .^ 2);
 s = ones (1, size (Pi, 2));
 s(t > 0) = sqrt ((max (sum (Kii .^ 2))) ./ t(t > 0));
 
-end % function compute_P_scaling
+end % function
