@@ -3,7 +3,7 @@
 % CALL: K = stk_materncov32_aniso (PARAM, X, Y)
 %
 %   computes the covariance matrix K between the sets of locations X and Y,
-%   using the anisotropic Matern covariance kernel with nu=3/2 and
+%   using the anisotropic Matern covariance function with nu=3/2 and
 %   parameters PARAM. The output matrix K has size NX x NY, where NX is the
 %   number of rows in X and NY the number of rows in Y. The vector of
 %   parameters must have DIM + 1 elements, where DIM is the common number
@@ -29,7 +29,7 @@
 
 % Copyright Notice
 %
-%    Copyright (C) 2015, 2016 CentraleSupelec
+%    Copyright (C) 2015, 2016, 2018 CentraleSupelec
 %    Copyright (C) 2011-2014 SUPELEC
 %
 %    Authors:  Julien Bect       <julien.bect@centralesupelec.fr>
@@ -41,7 +41,7 @@
 %    This file is part of
 %
 %            STK: a Small (Matlab/Octave) Toolbox for Kriging
-%               (http://sourceforge.net/projects/kriging)
+%               (https://github.com/stk-kriging/stk/)
 %
 %    STK is free software: you can redistribute it and/or modify it under
 %    the terms of the GNU General Public License as published by the Free
@@ -58,10 +58,6 @@
 
 function k = stk_materncov32_aniso (param, x, y, diff, pairwise)
 
-if nargin > 5,
-    stk_error ('Too many input arguments.', 'TooManyInputArgs');
-end
-
 persistent x0 y0 xs ys param0 pairwise0 D Kx_cache compute_Kx_cache
 
 % process input arguments
@@ -72,7 +68,7 @@ if nargin < 5, pairwise = false; end
 
 % check consistency for the number of factors
 dim = size (x, 2);
-if (size (y, 2) ~= dim),
+if (size (y, 2) ~= dim)
     stk_error ('xi and yi have incompatible sizes.', 'InvalidArgument');
 end
 
@@ -89,7 +85,7 @@ Sigma2 = exp (param(1));
 invRho = exp (param(2:end));
 
 % check parameter values
-if ~ (Sigma2 > 0) || ~ all (invRho >= 0),
+if ~ (Sigma2 > 0) || ~ all (invRho >= 0)
     error ('Incorrect parameter value.');
 end
 
@@ -108,20 +104,20 @@ if isempty (x0) || isempty (y0) || isempty (param0) ...
     compute_Kx_cache = true;
 end
 
-if diff == -1,
+if diff == -1
     %%% compute the value (not a derivative)
     k = Sigma2 * stk_rbf_matern32 (D, -1);
-elseif diff == 1,
+elseif diff == 1
     %%% diff wrt param(1) = log(Sigma2)
     k = Sigma2 * stk_rbf_matern32 (D, -1);
-elseif (diff >= 2) && (diff <= nb_params),
+elseif (diff >= 2) && (diff <= nb_params)
     %%% diff wrt param(diff) = - log(invRho(diff-1))
     ind = diff - 1;
     if compute_Kx_cache || isempty (Kx_cache)
         Kx_cache  = 1 ./ (D + eps) .* (Sigma2 * stk_rbf_matern32 (D, 1));
         compute_Kx_cache = false;
     end
-    if pairwise,
+    if pairwise
         k = (xs(:, ind) - ys(:, ind)).^2 .* Kx_cache;
     else
         k = (bsxfun (@minus, xs(:, ind), ys(:, ind)')) .^ 2 .* Kx_cache;
@@ -149,7 +145,6 @@ end % function
 %!test  K1 = stk_materncov32_aniso (param, x, y);
 %!test  K2 = stk_materncov32_aniso (param, x, y, -1);
 %!test  K3 = stk_materncov32_aniso (param, x, y, -1, false);
-%!error K0 = stk_materncov32_aniso (param, x, y, -1, false, pi^2);
 %!assert (isequal (K1, K2));
 %!assert (isequal (K1, K3));
 
